#
# spec file for package goldendict-ng
#
# Copyright (c) 2024 SUSE LLC
#
# All modifications and additions to the file contributed by third parties
# remain the property of their copyright owners, unless otherwise agreed
# upon. The license for this file, and modifications and additions to the
# file, is the same license as for the pristine package itself (unless the
# license for the pristine package is not an Open Source License, in which
# case the license is the MIT License). An "Open Source License" is a
# license that conforms to the Open Source Definition (Version 1.9)
# published by the Open Source Initiative.

# Please submit bugfixes or comments via https://bugs.opensuse.org/
#


%define __builder ninja
Name:           goldendict-ng
Version:        24.09.1
Release:        1.2
Summary:        Dictionary Lookup Program
License:        GPL-3.0-or-later
Group:          Productivity/Office/Dictionary
URL:            https://xiaoyifang.github.io/goldendict-ng/
Source0:        %{name}-%{version}.tar.xz
BuildRequires:  cmake
BuildRequires:  desktop-file-utils
BuildRequires:  gcc-c++
BuildRequires:  git
BuildRequires:  ninja
BuildRequires:  pkgconfig
BuildRequires:  unzip
# /Section dependencies
BuildRequires:  eb-devel
BuildRequires:  hunspell-devel >= 1.2.4
BuildRequires:  pkgconfig(libzim)
BuildRequires:  pkgconfig(opencc)
BuildRequires:  pkgconfig(vorbis)
BuildRequires:  pkgconfig(x11)
BuildRequires:  pkgconfig(xapian-core)
BuildRequires:  pkgconfig(xtst)
# /Section Qt
BuildRequires:  pkgconfig(Qt6Concurrent)
BuildRequires:  pkgconfig(Qt6Core)
BuildRequires:  pkgconfig(Qt6Core5Compat)
BuildRequires:  pkgconfig(Qt6Gui)
BuildRequires:  pkgconfig(Qt6Linguist)
BuildRequires:  pkgconfig(Qt6Multimedia)
BuildRequires:  pkgconfig(Qt6Svg)
BuildRequires:  pkgconfig(Qt6TextToSpeech)
BuildRequires:  pkgconfig(Qt6WebEngineWidgets)
BuildRequires:  pkgconfig(Qt6Widgets)
BuildRequires:  pkgconfig(Qt6Xml)
# /Section compresion libraries
BuildRequires:  pkgconfig(liblzma)
BuildRequires:  pkgconfig(bzip2)
BuildRequires:  pkgconfig(libzip)
BuildRequires:  pkgconfig(libzstd)
BuildRequires:  pkgconfig(lzo2)
BuildRequires:  pkgconfig(zlib)
# /Section ffmpeg 6
BuildRequires:  pkgconfig(libavformat)
BuildRequires:  pkgconfig(libavutil)
Requires:       qt6-multimedia
Provides:       goldendict = %{version}
Obsoletes:      goldendict < 1.5.1

%description
The Next Generation GoldenDict: A feature-rich dictionaries lookup program,
supporting many dictionary formats.

%lang_package -b goldendict-lang

%prep
%autosetup

%build
%cmake -DCMAKE_SKIP_INSTALL_RPATH:BOOL=ON
%cmake_build

%install
%cmake_install

%files
%license LICENSE.txt
%{_bindir}/goldendict
%{_datadir}/goldendict
%{_datadir}/applications/*.desktop
%{_datadir}/metainfo/*.metainfo.xml
%{_datadir}/pixmaps/goldendict.png
%exclude %{_datadir}/goldendict/locale/

%files lang
%{_datadir}/goldendict/locale/
%exclude %{_datadir}/goldendict/locale/crowdin.qm

%changelog
* Mon Dec 16 2024 Atri Bhattacharya <badshah400@gmail.com>
- Update to version 24.09.1:
  * Fix a Qt6.8 build error
  * Fix a minor, somewhat easy to trigger crash (Ctrl+F with no
    articles opened.)
- Switch to Qt6 builds.
- Use cmake for builds, qmake is no longer supported as a build
  tool by upstream.
- Pass CMAKE_SKIP_INSTALL_RPATH option to cmake to avoid rpaths in
  final executable.
- Drop Qt5 build support.
- Use ninja for build.
- Switch to obs_scm service (instead of tar_scm).
* Tue Jun  6 2023 slb <shenlebantongying@gmail.com>
- Drop the version.txt patch
* Mon Jun  5 2023 shenlebantongying <shenlebantongying@gmail.com>
- Build against Qt5 to avoid various regressions
* Sun Jun  4 2023 shenlebantongying <shenlebantongying@gmail.com>
- Add qt6-multimedia as runtime dependendcy (boo#1211979)
* Tue May 30 2023 shenlebantongying <shenlebantongying@gmail.com>
- Obsolete original pacakge's -lang
* Sat May 13 2023 shenlebantongying <shenlebantongying@gmail.com>
- Initial package
